#!/usr/bin/ksh
#
# Tektronix Phaser 750
# Advanced Printing self-extracting installation script.
#
KIT_COPYRIGHT="Copyright (c) 2003 Hewlett-Packard Company"

KIT_APS=APS
KIT_LPD=LPD
KIT_MINVER="V1.0"
KIT_TYPE=$KIT_APS
KIT_PRINTER="Tektronix Phaser 750"
KIT_FILES="Tektronix_Phaser750_PS.paf"

function setupInstructions {
	print "After the installation script has successfully completed, use the" >&2
	print "/usr/pd/scripts/pd_get_started script or pdprintadmin tool to create" >&2
	print "a new printer and queue." >&2
	print "" >&2
	print "For additional information refer to the Advanced Printing Software" >&2
	print "System Administration and Operation Guide." >&2
}


# Function:
#	askUser Prompt
#
# Description:
#	Prompt for a yes/no response. Default response is no.
#
# Arguments:
#	$1 Prompt Text
#
# Returns:
#	0 User entered yes
#	1 User entered no
#
function askUser {

	print "$1? <Y/N> \c" >&2
	read Response

	case "$Response" in
	[Yy])	return 0
		;;
	[Yy][Ee][Ss])
		return 0
		;;
	*)	return 1
		;;
	esac
}

# Function:
#	wrapMsg Text
#
# Description:
#	Pipe text to fold utility to make sure it will fit
#	within 80 characters.
#
# Arguments:
#	$1 Text, Message Text
#
# Returns:
#	n/a

function wrapMsg {
	print "$1" | fold -s >&2
}

# Function:
#	printLicenseAgreement
#
# Description:
#	Print license agreement
#
# Arguments:
#	None
#
# Returns:
#	Exits when the user does not agree to the terms of the license.

function PrintLicenseAgreement {

    wrapMsg "${KIT_COPYRIGHT}. All rights reserved.\n"

    msg1="                HEWLETT-PACKARD SOFTWARE PRODUCT"
    msg2="                  \"AS IS\" WARRANTY STATEMENT"
    wrapMsg "$msg1\n$msg2\n"

    msg1="DISCLAIMER. TO THE EXTENT ALLOWED BY LOCAL LAW, THIS HP SOFTWARE"
    msg2="PRODUCT (\"SOFTWARE\") IS PROVIDED TO YOU \"AS IS\" WITHOUT WARRANTIES OR"
    msg4="CONDITIONS OF ANY KIND, WHETHER ORAL OR WRITTEN, EXPRESS OR IMPLIED."
    msg5="HP SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTIES OR CONDITIONS OF"
    msg6="MERCHANTABILITY, SATISFACTORY QUALITY, NON-INFRINGEMENT AND FITNESS"
    msg7="FOR A PARTICULAR PURPOSE. Some countries, states and provinces do not"
    msg8="allow exclusions of implied warranties or conditions, so the above"
    msg9="exclusion may not apply to you. You may have other rights that vary"
    msg10="from country to country, state to state, or province to province."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 $msg5 $msg6 $msg7 $msg8 $msg9 $msg10 \n"

    msg1="LIMITATION OF LIABILITY. EXCEPT TO THE EXTENT PROHIBITED BY LOCAL LAW,"
    msg2="IN NO EVENT WILL HP OR ITS SUBSIDIARIES, AFFILIATES OR SUPPLIERS BE"
    msg3="LIABLE FOR DIRECT, SPECIAL, INCIDENTAL, CONSEQUENTIAL OR OTHER DAMAGES"
    msg4="(INCLUDING LOST PROFIT, LOST DATA, OR DOWNTIME COSTS), ARISING OUT OF"
    msg5="THE USE, INABILITY TO USE, OR THE RESULTS OF USE OF THE SOFTWARE,"
    msg6="WHETHER BASED IN WARRANTY, CONTRACT, TORT OR OTHER LEGAL THEORY, AND"
    msg7="WHETHER OR NOT ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. Your use of"
    msg8="the Software is entirely at your own risk. Should the Software prove"
    msg9="defective, you assume the entire cost of all service, repair or"
    msg10="correction. Some countries, states and provinces do not allow the"
    msg11="exclusion or limitation of liability for incidental or consequential"
    msg12="damages, so the above limitation may not apply to you."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 $msg5 $msg6 $msg7 $msg8 $msg9 $msg10 $msg11 $msg12 \n"

    msg1="NOTE. EXCEPT TO THE EXTENT ALLOWED BY LOCAL LAW, THESE WARRANTY TERMS"
    msg2="DO NOT EXCLUDE, RESTRICT OR MODIFY, AND ARE IN ADDITION TO, THE"
    msg3="MANDATORY STATUTORY RIGHTS APPLICABLE TO THE LICENSE OF THE SOFTWARE"
    msg4="TO YOU."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 \n"

}

# Function:
#	fileVersionTest Version PathFilename
#
# Description:
#	Fetch and compare the file version.
#
# Arguments:
#	$1 Version, The version of the file in this script
#	$2 PathFilename, path/filename of file to test
#
# Returns:
#	0 Script file older than installed file
#	1 Script file the same as installed file
#	2 Script file newier than install file
#
function fileVersionTest {

	new_ver=$(fixVersion $1)

	base=$(basename $2)
	ext=$(basename $2 | cut -f2 -d'.')
	case $ext in
	lpd)
		# Version format: 1.1.2.4
		old_ver=$(grep 'Revision:' $2 | cut -f4 -d\$ | cut -f2 -d: )
		;;
	paf)
		# Version format: APX-1-001 or 100
		old_ver=$(grep 'paf-x-file-version' $2 | cut -f2 -d\= )
		;;
	pcf)
		# Version format: 1.1.2.4
		old_ver=$(grep 'Revision:' $2 | cut -f4 -d\$ | cut -f2 -d: )
		;;
	pfo)
		# The version is not provided in all the files.
		# Version format: 1.0
		old_ver=$(grep 'FileVersion' $2 | cut -f2 -d\: )
		[[ -z $old_ver ]] && old_ver="0.0"
		;;
	[rp]pd)
		# Version format: "1.0"
		old_ver=$(grep '\*FileVersion' $2 | cut -f2 -d\: )
		;;
	*)
		# Lpd print filter?
		old_ver=$(what $2 | tr -s '@' '\n' | grep $base | grep 'Revision:' | cut -f4 -d\$ | cut -f2 -d: )
		;;
	esac

	old_ver=$(fixVersion $old_ver)

	# Are the versions the same?
	if [[ $new_ver = $old_ver ]] 
	then	# Yes
		return 1
	fi

	if [[ $new_ver > $old_ver ]]
	then
		# New file more current
		return 2
	else
		# System file more current
		return 0
	fi
}

# Function:
#	checkSumTest PathFilename CheckSum1 CheckSum2
#
# Description:
#	Fetch and compare the file version.
#
# Arguments:
#	$1 PathFilename, path/filename
#	$2 CheckSum1,  First checksum value generated from the 'sum' command.
#	$3 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Checksum matched
#	1 Checksum error
#
function checkSumTest {

	sum1=`sum $1 | tr -s "  " " " | cut -f 1 -d ' '`
	sum2=`sum $1 | tr -s "  " " " | cut -f 2 -d ' '`

	if [[ $sum1 -ne $2 ]] || [[ $sum2 -ne $3 ]]
	then
		return 1
	else
		return 0
	fi
}

# Function:
#	installTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Test to see if the directory exists and the file
#	uuencoded file is newier than the system file.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
function installTest {
	mkdir=0

	# Can't install the file if the directory doesn't exist.

	file_name=`basename $2`
	directory=`dirname $2`

	if [[ ! -d $directory ]]
	then
		if [[ $mkdir = 0 ]]
		then
			msg1="Error: File $file_name not installed because"
			msg2="directory $directory doesn't exist."
			wrapMsg "$msg1 $msg2"
			return 1
		else
			mkdir $directory
			chmod 755 $directory
			chown root:system $directory
		fi
	fi

	# If the file does not exist, it's ok to install.
	if [[ ! -e $2 ]]
	then
		return 0
	fi

	fileVersionTest $1 $2
	status=$?

	if [[ $status = 1 ]]
	then
		checkSumTest $2 $3 $4
		if [[ $? = 0 ]]
		then
			# Files are the same, don't install
			wrapMsg "The $file_name system file is current and will not be replaced.\n"
			return 1
		else
			# Versions are the same, but the files are different!
			print "Warning: File versions match but the files are different!">&2
			askUser "Replace $file_name"
			return $?
		fi
	fi

	if [[ $status = 0 ]]
	then
		wrapMsg "The $file_name system file is newier and will not be replaced.\n"
		return 1
 	fi

	return 0
}

# Function:
#	mimimumVersionTest version
#
# Description:
#	Test to see if the minimum application or operating version 
#	requirement is met.
#
# Arguments:
#	$1 Version,    Minimum install version requirement
#
# Returns:
#	0 test passed
#	1 test failed
#
function mimimumVersionTest {

	if [[ $KIT_TYPE = $KIT_APS ]]
	then
		# At this time there isn't a minimum APS requirement.
		return 0 
	fi

	# The only other kit type is LPD, so check the OS version.

	# Note: The version field moves 1 position between Digital UNIX
	#       and Compaq Tru64 UNIX, but is always before (Rev.
	temp=` strings /vmunix | grep '(Rev.' | grep UNIX | cut -f1 -d '(' `

	# The version is the last value
	for x in $temp
	{
	  osver=$x
	}

	# A field test version of the OS might not start with a V. At some
	# point we might need to note the difference, but for now we don't.
	# Modify the version string by replacing the first character with a V.

	temp=$osver
	osver="V$( echo "$osver" | cut -c2- )"

	if [[ $osver < $1 ]]
	then
		return 1
	fi

	return 0
}

# Function:
#	installLpdTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	If the file does not currently exist and the minimal install
#	requirements are met, a success status is returned.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Exits:
#	Exit if the minimum OS requirement is not met.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
#
function installLpdTest {

	file_name=`basename $2`
	file_ext=`print "$file_name" | cut -f2 -d'.'`

	# Perform the OS test after this test. No reason to complain
	# about the os version if the file isn't going to be installed.
	if [[ $file_ext = "lpd" ]]
	then
		# If this is a .lpd file and the base directory doesn't exist
		# return.
		if [[ ! -d `dirname $2` ]]
		then
			msg1="File $file_name is not required for this version of Tru64 UNIX.\n"
			wrapMsg "$msg1"
			return 1
		fi
	fi

	installTest $1 $2 $3 $4
	return $?
}


# Function:
#	installApsTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Test the minimal install requirements for an APS file. 
#
# Arguments:
#	$1 File version, File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
#

function installApsTest {

	installTest $1 $2 $3 $4
	return $?
}

# Function:
#	fixVersion Version
#
# Description:
#	Remove unwanted characters.
#	Aps two version formats are converted to a common format.
#
# Arguments:
#	$1 Version, Version string
#
# Returns:
#	The updated version string.
#
function fixVersion {

	# Remove quotes, tabs, and spaces
	ver=$(echo $1 | tr -d "\"\t ")

	# Set null strings to version 0
	if [[ -z $ver ]]
	then
		ver=0
	fi

	# If the version starts with 'a', convert
	# a???-x-xxx to xxxx
	case $ver in
	[Aa]*)	;;
	[0123456789]*)
		# Return the version
		print "$ver"
		return
		;;
	*)	# Don't know what we found so return a version of 0.
		print "0.0"
		;;
	esac

	# To compare version 100 to apx-?-??? convert
	# apx-1-001 to 1001
	# apx-1-2   to 1002
	part1=$(echo "$ver" | cut -f2 -d\-)
	part2=$(echo "$ver" | cut -f3 -d\-)

	ver=$(printf "%s%.3d" $part1 $part2)

	# Return the version
	print "$ver"
	return
}

# Function:
#	preInstall FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Determine if this is an APS or LPD install and call the
#	appropriate function.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file
#	1 Don't install file
#
function preInstall {

	status=1

	if [[ $KIT_TYPE = $KIT_LPD ]] 
	then
		installLpdTest $1 $2 $3 $4
		status=$?
	fi

	if [[ $KIT_TYPE = $KIT_APS ]] 
	then
		installApsTest $1 $2 $3 $4
		status=$?
	fi

	# On install status, backup existing file
	# if it exists
	if [[ $status = 0 ]]
	then
		if [[ -e $2 ]]
		then
			# format = filename_yyyymmmdd_hh:mm:ss
			backup=$2_$(date +"b%d_%T")
			mv $2 $backup
			wrapMsg "Backup file $backup created."

			# Return the name of the backup file
			print "$backup"
		fi
	fi
	return $status
}

# Function:
#	postInstall BackupFile Owner Group Protection FileName CheckSum1 CheckSum2
#
# Description:
#	After the file has been installed verify the file checksum. If
#	the checksum is ok, set the file owner and protection.
#
#	Notify the user of a checksum error and prompt to remove the file.
#
# Arguments:
#	$1 BackupFile, Name of the backup file
#	$2 Owner,      File owner for chown command
#	$3 Group,      Group owner for chgrp command
#	$4 Protection, File protections number, eg 644, for chmod command
#	$5 FileName,   Installed file path/filename
#	$6 CheckSum1,  First checksum value generated from the 'sum' command.
#	$7 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	None
#
function postInstall {

	chown $2:$3 $5
	chmod $4 $5

	checkSumTest $5 $6 $7
	if [[ $? != 0 ]]
	then
		wrapMsg "Install checksum error on file $5!"

		if [[ ! -z $1 ]]
		then
			askUser "Restore the backup file"
		else
			askUser "Delete the file $5"
		fi

		if [[ $? = 0 ]]
		then 
			rm $5
			if [[ ! -z $1 ]]
			then
				mv $1 $5
				wrapMsg "Backup file restored.\n"
			else
				wrapMsg "File $5 deleted.\n"
			fi
		fi
	else
		wrapMsg "File $5 installed.\n"
		FileInstalled=1
	fi
	return
}

# Function:
#	doHelp
#
# Description:
#	Display the install script options.
#
# Arguments:
#	None
#
# Returns:
#	None
#
function doHelp {
	print "Synopsis: $(basename $0) -option" >&2
	print "" >&2
	print "Options:  -i Install files" >&2
	print "          -p Printer configuration instructions" >&2
	print "" >&2
	return
}

#
# Program
#

typeset -xi FileInstalled=0

# Identify the program

if [[ $KIT_TYPE = $KIT_LPD ]]
then
	print "LPD \c"

elif [[ $KIT_TYPE = $KIT_APS ]]
then
	print "Advanced Printing Software \c"
fi

print "installation kit for: $KIT_PRINTER\n"


# When no arguments are provided, display the help text and exit.
if [[  $# = 0 ]]
then
	doHelp
	exit 0
fi

while getopts :hip opt
do
        case $opt in
	h)	doHelp
		exit 0
		;;
	i)	# Install, fall out of case statement
		;;
	p)	# Print post-install setup instructions
		setupInstructions
		exit 0
		;;
	\?)	doHelp
		exit 0
                ;;
        esac
done

UserName=`whoami`

if [[ $UserName != "root" ]]
then
	print "You must be root to run this program."
	exit 1
fi

mimimumVersionTest $KIT_MINVER
if [[ $? != 0 ]]
then
	msg1="This installation requires a minimum"
	msg2="operating system version of $1."
	wrapMsg "$msg1 $msg2"
	exit 1
fi

subset_name=UNKNOWN
if [[ $KIT_TYPE = $KIT_LPD ]]
then
	subset_name=OSFPRINT
elif [[ $KIT_TYPE = $KIT_APS ]]
then
	subset_name=APXBASE
else
	print "Error: Unknown kit type."
	exit 1
fi

if [ ! -e /usr/.smdb./$subset_name*.lk ]
then
	print "The update requires the $subset_name subset to be installed."
	exit 1
fi

print "This kit contains the following files:\n"

echo "$KIT_FILES" | fold -s
print ""

PRESS_ENTER='Press ENTER to continue'

printf "$PRESS_ENTER"
read temp

PrintLicenseAgreement 2>&1 | pg -e -p "$PRESS_ENTER" >&2

askUser "Do you accept the terms in the license agreement"
if [[ $? != 0 ]]
then
	# User did not accept license agreement.
	print "No files were installed."
	exit 1
fi
print "\n\n"

#--- uuencoded files ---
backup_file=$(preInstall "APX-1-001" /usr/pd/share/cap/Tektronix_Phaser750_PS.paf 39529 4)
if [[ $? = 0 ]]
then
uudecode << 'EndOfEncodedFile'
begin 644 /usr/pd/share/cap/Tektronix_Phaser750_PS.paf
M(R!0<FEN=&5R($%T=')I8G5T92!&:6QE(&9O<B!496MT<F]N:7@@4&AA<V5R
M(#<U,"!P<FEN=&5R"B,@4F5V+B`P-RU-87DM,C`P,0HC"B,@0V]P>7)I9VAT
M(#(P,#$@0V]M<&%Q($-O;7!U=&5R($-O<G!O<F%T:6]N+B!!;&P@4FEG:'1S
M(%)E<V5R=F5D+@HC"B,@5&5K=')O;FEX(&ES(&$@=')A9&5M87)K(&]F(%1E
M:W1R;VYI>"!);F-O<G!O<F%T960N"B,@4&AA<V5R(&ES(&$@=')A9&5M87)K
M(&]F(%AE<F]X($-O<G!O<F%T:6]N+@HC(%!O<W138W)I<'0@:7,@82!T<F%D
M96UA<FL@;V8@061O8F4@4WES=&5M<R!);F-O<G!O<F%T960N"B,*(R!0<FEN
M=&5R($YO=&5S"B,)4V5T('1H92!C;VYS;VQE(&1E9F%U;'0@:6YP=70@=')A
M>2!T;R!P87!E<BP@;F]T('1R86YS<&%R96YC>2X*(PE3970@=&AE(&-O;G-O
M;&4@9&5F875L="!O=71P=70@=&\@9F%C92!D;W=N+@HC"B,)5VAE;B!T:&4@
M<V5L96-T960@:6YP=70@=')A>2!I<R!T:&4@=')A;G-P87)E;F-Y('1R87D@
M;W(@=&AE(`HC"6UA;G5A;"!I;G!U="!T<F%Y+"!T:&4@;W5T<'5T('=I;&P@
M8F4@<')I;G1E9"!F86-E('5P+B`@5&AI<PHC"6ES(&1O8W5M96YT960@:6X@
M=&AE('!R:6YT97(@;6%N=6%L+@H*<&%F+7@M9FEL92UN86UE/2)496MT<F]N
M:7A?4&AA<V5R-S4P7U!3+G!A9B(*<&%F+7@M9FEL92UV97)S:6]N/2)!4%@M
M,2TP,#$B"@IP<FEN=&5R+6UO9&5L/2)496MT<F]N:7@@4&AA<V5R(#<U,"!3
M97)I97,@4%,B"FUA>&EM=6TM<')I;G1E<BUS<&5E9#TQ-@H*;F%T:79E+61O
M8W5M96YT+69O<FUA=',M<F5A9'D](E!O<W138W)I<'0B"F1O8W5M96YT+69O
M<FUA=',M<W5P<&]R=&5D/2)0;W-T4V-R:7!T(B`B<VEM<&QE+71E>'0B"F1O
M8W5M96YT+69O<FUA=',M<F5A9'D](E!O<W138W)I<'0B(")S:6UP;&4M=&5X
M="(*"G!L97AE<RUS=7!P;W)T960](G-I;7!L97@B"G-I9&5S+7-U<'!O<G1E
M9#TB,2(*<VED97,M<F5A9'D](C$B"@II;G!U="UT<F%Y<RUS=7!P;W)T960]
M(FUA;G5A;"(@(G1O<"(*:6YP=70M=')A>7,M<F5A9'D](FUA;G5A;"(@(G1O
M<"(*"B,@<')I=F%T92!S=7!E<G9I<V]R(&%T=')I8G5T97,*"G!A9BUI<RUP
M:FP]9F%L<V4*<&%F+6YA=&EV92UD;V-U;65N="UF;W)M870M,3TB4&]S=%-C
M<FEP="(*<&%F+61E9F%U;'0M9&]C=6UE;G0M9F]R;6%T/2)0;W-T4V-R:7!T
M(@IP868M:F]B+7-E<&%R871O<BUF;W)M870](E!O<W138W)I<'0B"@HC(&-O
M;FYE8W1I;VXM<F5L871E9"!A='1R:6)U=&5S"@IP868M8V]N;F5C=&EO;BUL
M979E;"UP87)A;&QE;#TR"G!A9BUC;VYN96-T:6]N+6QE=F5L+6EP+7-O8VME
M=#TS"G!R:6YT97(M=&-P:7`M<&]R="UN=6UB97(].3$P,`H*(R!01$PM9&5P
M96YD96YT(&-O;6UA;F1S"@IP868M<W1A<G0M<&1L+3$M8V]M;6%N9#TB7%PP
M,3(E(5Q<,#$R(@H*(R!);G!U="!T<F%Y('-E;&5C=&EO;@HC"B,@5&AE(&1U
M<&QE>"!U;FET(')E<&QA8V5S('1H92!T;W`@<&%P97(@8V%S<V5T=&4@=')A
M>2X@5VAE;B!I;G-T86QL960L('1H90HC('1O<"!T<F%Y(&ES(&YO="!A=F%I
M;&%B;&4@8F5C875S92!I="!D;V5S;B=T(&-O;G1A:6X@86YY('!A<&5R+@HC
M"B,@1&5V:6-E('1R87D@;F%M92`@("`@("`@("`@3TE$('1R87D@;F%M92`@
M(%1R87D@3G5M8F5R("`@(%-T86YD87)D+T]P=&EO;F%L"B,@+2TM+2TM+2TM
M+2TM+2TM+2`@("`@("`@("`@+2TM+2TM+2TM+2TM+2`@("TM+2TM+2TM+2TM
M("`@("TM+2TM+2TM+2TM+2TM+2TM"B,@375L=&DM<'5R<&]S92!087!E<B`@
M("`@("`@;6%N=6%L("`@("`@("`@("`@("`@+2`@("`@("`@(%-T86YD87)D
M"B,@57!P97(@;W(@1'5P;&5X(%5N:70@("`@("`@=&]P("`@("`@("`@("`@
M("`@("`@,2`@("`@("`@(%-T86YD87)D"B,@36ED9&QE("`@("`@("`@("`@
M("`@("`@("`@;6ED9&QE("`@("`@("`@("`@("`@,B`@("`@("`@($]P=&EO
M;F%L"B,@3&]W97(@("`@("`@("`@("`@("`@("`@("`@8F]T=&]M("`@("`@
M("`@("`@("`@,R`@("`@("`@($]P=&EO;F%L"@HC('!A9BUI;G!U="UT<F%Y
M<RUP;W-S:6)L90HQ+C(N.#0P+C$Q,S4U,"XQ+C,N,BXQ,C`N.#,](FUA;G5A
M;"!T;W`@;6ED9&QE(&)O='1O;2`Q(#(@,R(*"B,@<&%F+6EN<'5T+71R87DM
M86QI87-E<PHQ+C(N.#0P+C$Q,S4U,"XQ+C,N,BXQ,C`N-#(](C$Z=&]P(#(Z
M;6ED9&QE(#,Z8F]T=&]M(@H*(R!.=6UB97)E9"!T<F%Y(&YA;65S(&%R92!S
M=7!P;W)T960@:6X@<&1S<'9R(%8Q+C$@86YD(&QA=&5R"@IP868M;6%N=6%L
M+6EN<'5T+6-O;6UA;F0M,3TB(#P\("]-961I85!O<VET:6]N(#,@+TUE9&EA
M0VQA<W,@;G5L;"`O5')A>5-W:71C:"!F86QS92`O36%N=6%L1F5E9"!F86QS
M92`^/B!S971P86=E9&5V:6-E("(*<&%F+71O<"UI;G!U="UC;VUM86YD+3$]
M(B`\/"`O365D:6%0;W-I=&EO;B`P("]-961I84-L87-S(&YU;&P@+U1R87E3
M=VET8V@@9F%L<V4@+TUA;G5A;$9E960@9F%L<V4@/CX@<V5T<&%G961E=FEC
M92`B"G!A9BUM:61D;&4M:6YP=70M8V]M;6%N9"TQ/2(@/#P@+TUE9&EA4&]S
M:71I;VX@,2`O365D:6%#;&%S<R!N=6QL("]4<F%Y4W=I=&-H(&9A;'-E("]-
M86YU86Q&965D(&9A;'-E(#X^('-E='!A9V5D979I8V4@(@IP868M8F]T=&]M
M+6EN<'5T+6-O;6UA;F0M,3TB(#P\("]-961I85!O<VET:6]N(#(@+TUE9&EA
M0VQA<W,@;G5L;"`O5')A>5-W:71C:"!F86QS92`O36%N=6%L1F5E9"!F86QS
M92`^/B!S971P86=E9&5V:6-E("(*"B,@3W5T<'5T(&)I;B!S96QE8W1I;VX*
M("`*(R!$979I8V4@8FEN(&YA;65S("`@("`@("`@("`@("!/240@8FEN(&YA
M;65S"B,@+2TM+2TM+2TM+2TM+2TM+2`@("`@("`@("`@("`@+2TM+2TM+2TM
M+2TM+0HC(%1O<"`H9&5F875L="P@1F%C92!$;W=N*2`@("`@('1O<"P@9F%C
M92UD;W=N"B,@3&5F="!":6X@*$9A8V4@57`I("`@("`@("`@("`@;&5F="P@
M9F%C92UU<`HC"B,@<&%F+6]U='!U="UB:6YS+7!O<W-I8FQE"C$N,BXX-#`N
M,3$S-34P+C$N,RXR+C$R,"XX-#TB=&]P(&9A8V4M9&]W;B!L969T(&9A8V4M
M=7`B"@HC($YO=&4Z($%D9"!S=7!P;W)T(&9O<B!O<'1I;VYS(&)Y('5S:6YG
M('!D<V5T(&]R('!D<')I;G1A9&UI;B!T;R`*(R`@("`@("!A9&0@3TE$(&YA
M;65S('1O(&]U='!U="UB:6YS+7-U<'!O<G1E9"!A;F0@;W5T<'5T+6)I;G,M
M<F5A9'DN"@IP868M=&]P+6]U='!U="UC;VUM86YD+3$](B`\/"`O3W5T<'5T
M1F%C955P(&9A;'-E(#X^('-E='!A9V5D979I8V4@(@IP868M9F%C92UD;W=N
M+6]U='!U="UC;VUM86YD+3$](B`\/"`O3W5T<'5T1F%C955P(&9A;'-E(#X^
M('-E='!A9V5D979I8V4@(@IP868M;&5F="UO=71P=70M8V]M;6%N9"TQ/2(@
M/#P@+T]U='!U=$9A8V55<"!T<G5E(#X^('-E='!A9V5D979I8V4@(@IP868M
M9F%C92UU<"UO=71P=70M8V]M;6%N9"TQ/2(@/#P@+T]U='!U=$9A8V55<"!T
M<G5E(#X^('-E='!A9V5D979I8V4@(@H*(R!3:61E<R!S96QE8W1I;VX*"G!A
M9BUS970M<VEM<&QE>"UC;VUM86YD+3$](B`\/"]$=7!L97@@9F%L<V4@+U1U
M;6)L92!F86QS93X^('-E='!A9V5D979I8V4@(@IP868M<V5T+61U<&QE>"UC
M;VUM86YD+3$](B`\/"]$=7!L97@@=')U92`O5'5M8FQE(&9A;'-E/CX@<V5T
M<&%G961E=FEC92`B"G!A9BUS970M='5M8FQE+6-O;6UA;F0M,3TB(#P\+T1U
M<&QE>"!T<G5E("]4=6UB;&4@=')U93X^('-E='!A9V5D979I8V4@(@H*(R!%
#;F0*
`
end
EndOfEncodedFile
postInstall "$backup_file" bin bin 644 /usr/pd/share/cap/Tektronix_Phaser750_PS.paf 39529 4
fi

exit 0
